/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2017 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef __SETUPSCRIPTAPI_H__
#define __SETUPSCRIPTAPI_H__

class Preferences;
class QScriptEngine;

void setupScriptApi(QScriptEngine *engine, Preferences *pPreferences = 0);

#endif
